/**
 * Created by HuDianxing on 2017-04-15.
 *
 * Detonger Label Printer Encapsulation of JavaScript Interface.
 *
 * Copyright(C) 2010~2018, Shanghai Daozhen Technology Co., Ltd.
 *
 */
var LPAPI = (function () {

    /**
     * Object Initialization.
     * @param lpapi Android Interface name specified when adding the JS interface to the code,
     *  If specified name is "DzLPAPI" in Android, then you need to use "window.DzLPAPI" to represent this interface in JS.
     * @constructor
     */
    function LPAPI(lpapi) {
        this.DzLPAPI = (lpapi == null ? window.DzLPAPI : lpapi);
    };

    /***************************************************************************
     * Printer on and off operation.
     **************************************************************************/

    /**
     *  Returns the names of all installed printers as a string, separated by ",".
     */
    LPAPI.prototype.getAllPrinters = function (printerName) {
        return this.DzLPAPI.getAllPrinters(printerName || "");
    };

    /**
     *  Turns on the printer with the specified name (asynchronous call).
     * @param printerName
     *            Printer Name. Printer name type:
	 *            1、Empty string: opens the first supported printer on the current client system;
	 *            2、Printer model: e.g. DT20S；
	 *            3、Printer name: e.g. DT20S-60901687;
	 *            4、MAC address: open the printer at the specified address, e.g. 00:18:E4:0C:68:CA.
     */
    LPAPI.prototype.openPrinter = function (printerName) {
        return this.DzLPAPI.openPrinter(printerName);
    };

    /**
     *  Turns on the printer with the specified name (synchronized call).
     * @param printerName
     *              Printer Name. Printer name type:
	 *            1、Empty string: opens the first supported printer on the current client system;
	 *            2、Printer model: e.g. DT20S；
	 *            3、Printer name: e.g. DT20S-60901687;
	 *            4、MAC address: open the printer at the specified address, e.g. 00:18:E4:0C:68:CA.
     */
    LPAPI.prototype.openPrinterSync = function (printerName) {
        return this.DzLPAPI.openPrinterSync(printerName);
    };

    /**
     *  Get the name of the printer currently in use.
     *
     * @return Return the name of the printer currently in use if a printer is connected, otherwise return the empty string.
     */
    LPAPI.prototype.getPrinterName = function () {
        return this.DzLPAPI.getPrinterName();
    };

    /**
     * Determine whether the current printer is turned on (connected successfully)?
     */
    LPAPI.prototype.isPrinterOpened = function () {
        return this.DzLPAPI.isPrinterOpened();
    };

    /**
     *  Disconnect the current printer.
     */
    LPAPI.prototype.closePrinter = function () {
        this.DzLPAPI.closePrinter();
    };

    /**
     * Reconnect the last connected printer (asynchronous call).
     *
     * @return Whether the asynchronous connection operation was successfully submitted?
     * 		Note: Returning success only means that the operation was submitted successfully, it does not mean that the connection was successful, the specific connection result will be notified through the callback function.
     */
    LPAPI.prototype.reopenPrinter = function () {
        return this.DzLPAPI.reopenPrinter();
    };

    /**
     * Reconnect the last connected printer (synchronized call).
     *
     * @return  Was the synchronized connection operation successful?
     */
    LPAPI.prototype.reopenPrinterSync = function () {
        return this.DzLPAPI.reopenPrinterSync();
    };

    /**
     *  Exit all operations related to printing.
     */
    LPAPI.prototype.quit = function () {
        this.DzLPAPI.quit();
    };

    /***************************************************************************
     * Print job start, pagination, and end operations.
     **************************************************************************/

    /**
     * Start a print job with the specified parameters.
     *
     * @param width
     *            Label width (in mm)
     * @param height
     *            Label height (in mm)
     * @param orientation
     *            Label printing direction. 0: no rotation; 90: rotate 90 degrees clockwise; 180: rotate 180 degrees; 270: rotate 90 degrees counterclockwise.
     * @return Successful or not?
     */
    LPAPI.prototype.startJob = function (width, height, rotation) {
        return this.DzLPAPI.startJob(width, height, rotation);
    };

    /**
     *  Start a print page.
     */
    LPAPI.prototype.startPage = function () {
        return this.DzLPAPI.startPage();
    };

    /**
     * End a print page.
     */
    LPAPI.prototype.endPage = function () {
        this.DzLPAPI.endPage();
    };

    /**
     * End draw task
     */
    LPAPI.prototype.endJob = function () {
        this.DzLPAPI.endJob();
    };

    /**
     *  Cancel draw task for canceling all draw operations before the task is submitted.
     */
    LPAPI.prototype.abortJob = function () {
        this.DzLPAPI.abortJob();
    };

    /**
     * Submit the print data for real printing.
     */
    LPAPI.prototype.commitJob = function () {
        return this.DzLPAPI.commitJob();
    };

    /**
     * Cancel the current print operation is used to perform a cancel operation after submitting a print job.
     */
    LPAPI.prototype.cancel = function () {
        this.DzLPAPI.cancel();
    };

    /***************************************************************************
     *Print parameter settings.
     **************************************************************************/

	/**
	 * Set the values of drawing-related parameters.
	 * 
	 * @param name
	 *             The name of the parameter, as defined in DrawParamName.
	 * @param value
	 *            Parameter values, refer to the different parameter names for exact meanings.
	 */
	LPAPI.prototype.setDrawParam = function (name, value) {
		this.DzLPAPI.setDrawParam(name, value);
	}

    /**
     * Get the clockwise rotation angle of the current print action.
     *
     * @return  clockwise rotation angle of the current print action（0，90，180，270）.
     */
    LPAPI.prototype.getItemOrientation = function () {
        return this.DzLPAPI.getItemOrientation();
    };

    /**
     * Set the rotation angle of the print action.
     *
     * @param orientation
     *            orientation: Rotation angle. The parameters are described as follows:
     *            0：non-rotating;
     *            90：Rotate 90 degrees clockwise;
     *            180：Rotate 180 degrees;
     *            270：Rotate 90 degrees counter-clockwise.
     */
    LPAPI.prototype.setItemOrientation = function (orientation) {
        this.DzLPAPI.setItemOrientation(orientation);
    };

    /**
     * Get the horizontal alignment of the current print action.
     *
     * @return The horizontal alignment for subsequent print actions. The horizontal alignment values are as follows:
     *         0：Horizontal Left;
     *         1：Horizontal Centering;
     *         2：Horizontal Right;
     */
    LPAPI.prototype.getItemHorizontalAlignment = function () {
        return this.DzLPAPI.getItemHorizontalAlignment();
    };

    /**
     * Set the horizontal alignment of the print action.
     *
     * @param alignment
     *            Horizontal alignment mode. The parameters are described below:
     *            0： Horizontal Left (default setting);
     *            1：Horizontal Centering;
     *            2：Horizontal Right;
     */
    LPAPI.prototype.setItemHorizontalAlignment = function (alignment) {
        this.DzLPAPI.setItemHorizontalAlignment(alignment);
    };

    /**
     *  Get the vertical alignment of the current print action.
     *
     * @return The vertical alignment of the subsequent print action. The return result is described below:
     *         0：vertical on top;
     *         1：vertical centering;
     *         2：vertical bottom;
     */
    LPAPI.prototype.getItemVerticalAlignment = function () {
        return this.DzLPAPI.getItemVerticalAlignment();
    };

    /**
     * Set the Vertical Alignment of Print Actions.
     *
     * @param alignment
     *            Vertical alignment with the following parameter description:
      *         0：vertical on top;
     *         1：vertical centering;
     *         2：vertical bottom;
     */
    LPAPI.prototype.setItemVerticalAlignment = function (alignment) {
        this.DzLPAPI.setItemVerticalAlignment(alignment);
    };

    /**
     * Get line brush alignment.
     *
     * @return  line brush alignment（{@link PenAlignment}），<br>
     *         The value is one of the following：<br>
     *         PenAlignment.CENTER：The line drawn is centered at the specified position；<br>
     *         PenAlignment.INSET：The drawn line is inside the specified position<br>
     */
    LPAPI.prototype.getItemPenAlignment = function () {
        return this.DzLPAPI.getItemPenAlignment();
    };

    /**
     * Set the line brush alignment.
     *
     * @param penAlignment
     *            Line brush alignment（{@link PenAlignment}），<br>
     *            The value is one of the following：<br>
     *            PenAlignment.CENTER：The line drawn is centered at the specified position； <br>
     *            PenAlignment.INSET：The drawn line is inside the specified position.
     */
    LPAPI.prototype.setItemPenAlignment = function (penAlignment) {
        this.DzLPAPI.setItemPenAlignment(penAlignment);
    };

    /***************************************************************************
     *  Drawing operations for print objects.
     **************************************************************************/

    /**
     * Print Text.
     *
     * @param text
     *             Text content.
     * @param x
     *             The position of the print object (in mm).
     * @param y
     *            The position of the print object (in mm).
     * @param width
     *            The width of the print object (in mm).
     * @param height
     *            The height of the print object (in mm).
     *           When height is 0, the true height of the printed text will be expanded according to the content; otherwise, when the specified height is not enough to print the specified text, the font will be automatically reduced to fit the specified height for text printing.
     * @param fontHeight
     *            The font height of the text (in mm).
     * @param fontStyle
     *            The font style of the text (can be combined by bit), can not be specified, the default is 0 (normal). 0: Normal; 1: Bold; 2: Italic; 3: Bold Italic; 4: Underline; 8: Strikethrough.
     * @param lineSpace
	 *           line spacing, do not need additional line spacing, then set 0 can be, 1 indicates that the current font double the line spacing;
	 * @param autoIndent
	 *            true: When a colon (":") is detected in a string, the parts before and after the colon are aligned separately;
     * @return Print successful or not?
     */
    LPAPI.prototype.drawText = function (text, x, y, width, height, fontHeight, fontStyle, lineSpace, autoIndent, autoScale) {
    	lineSpace = lineSpace || 0;
    	autoIndent = autoIndent || false;
    	autoScale = autoScale || false;
    
    	if (autoScale)
            return this.DzLPAPI.drawTextWithScale(text, x, y, width, height, fontHeight, fontStyle, lineSpace, autoIndent);
        else if (autoIndent)
            return this.DzLPAPI.drawTextWithIndent(text, x, y, width, height, fontHeight, fontStyle, lineSpace);
        else if (fontStyle || lineSpace)
            return this.DzLPAPI.drawTextRegular(text, x, y, width, height, fontHeight, fontStyle, lineSpace);
        else
            return this.DzLPAPI.drawText(text, x, y, width, height, fontHeight);
    };

    /**
     * Prints a rectangular box with the specified line width.
     *
     * @param x
     *            Horizontal position of the upper left corner of the drawn rectangular box (in mm).
     * @param y
     *            Vertical position of the upper left corner of the drawn rectangular box (in mm).
     * @param width
     *            Horizontal width of the drawn rectangular box (in mm).
     * @param height
     *            Vertical height of the drawn rectangular box (in mm).
     * @param lineWidth
     *             The line width of the rectangular box (in mm). The line width of the rectangular frame is extended toward the inside of the rectangular frame.
     * @return  Print successful or not?
     */
    LPAPI.prototype.drawRectangle = function (x, y, width, height, lineWidth) {
        return this.DzLPAPI.drawRectangle(x, y, width, height, lineWidth);
    };

    /**
     *  Print the filled rectangular box.
     *
     * @param x
     *            Horizontal position of the upper left corner of the drawn filled rectangular box (in mm).
     * @param y
     *            Vertical position of the upper left corner of the drawn filled rectangular box (in mm).
     * @param width
     *            Horizontal width of the drawn filled rectangular box (in mm).
     * @param height
     *            Vertical height of the drawn filled rectangular box (in mm).
     * @return Print successful or not?
     */
    LPAPI.prototype.fillRectangle = function (x, y, width, height) {
        return this.DzLPAPI.fillRectangle();
    };

    /**
     * Print rounded rectangular boxes with the specified line width.
     *
     * @param x
     *            Horizontal position of the upper left corner of the drawn rounded rectangular box (in mm).
     * @param y
     *            Vertical position of the upper left corner of the drawn rounded rectangular box (in mm).
     * @param width
     *            Horizontal width of the drawn rounded rectangular box (in mm).
     * @param height
     *            Vertical height of the drawn rounded rectangular box (in mm).
     * @param cornerWidth
     *            Width of rounded corners (in mm).
     * @param cornerHeight
     *            Height of rounded corners (in mm).
     * @param lineWidth
     *            The line width of the rounded rectangle box (in mm). The line width of the rounded rectangle box extends to the inside of the rounded rectangle box.
     * @return Print successful or not?
     */
    LPAPI.prototype.drawRoundRectangle = function (x, y, width, height, cornerWidth, cornerHeight, lineWidth) {
        return this.DzLPAPI.drawRoundRectangle(x, y, width, height, cornerWidth, cornerHeight, lineWidth);
    };

    /**
     * Print filled rounded rectangular boxes.
     *
     * @param x
     *            Horizontal position of the upper left corner of the drawn filled rounded rectangular box (in mm).
     * @param y
     *            Vertical position of the upper left corner of the drawn filled rounded rectangular box (in mm).
     * @param width
     *            Horizontal width of the drawn filled rounded rectangular box (in mm).
     * @param height
     *            Vertical height of the drawn filled rounded rectangular box (in mm).
     * @param cornerWidth
     *             Rounded corner width (in mm).
     * @param cornerHeight
     *             Rounded corner height  (in mm).
     * @return Print successful or not?
     */
    LPAPI.prototype.fillRoundRectangle = function (x, y, width, height, cornerWidth, cornerHeight) {
        return this.DzLPAPI.fillRoundRectangle(x, y, width, height, cornerWidth, cornerHeight);
    };

    /**
     * Print an ellipse/circle with the specified line width.
     *
     * @param x
     *            Horizontal position of the upper left corner of the drawn ellipse (in mm).
     * @param y
     *            Vertical position of the upper left corner of the drawn ellipse (in mm).
     * @param width
     *            Horizontal width of the drawn ellipse (in mm).
     * @param height
     *             Vertical height of the drawn ellipse (in mm).
     * @param lineWidth
     *             The line width of the ellipse (in mm). The line width of an ellipse is extended toward the interior of the ellipse.
     * @return Print successful or not?
     */
    LPAPI.prototype.drawEllipse = function (x, y, width, height, lineWidth) {
        return this.DzLPAPI.drawEllipse(x, y, width, height, lineWidth);
    };

    /**
     *  Print the filled ellipse/circle.
     *
     * @param x
     *            Horizontal position of the upper left corner of the drawn filled ellipse (in mm).
     * @param y
     *           Vertical position of the upper left corner of the drawn filled ellipse (in mm).
     * @param width
     *            Horizontal width of the drawn filled ellipse (in mm).
     * @param height
     *            Vertical height (in mm) of the drawn filled ellipse.
     * @return Print successful or not?
     */
    LPAPI.prototype.fillEllipse = function (x, y, width, height) {
        return this.DzLPAPI.fillEllipse(x, y, width, height);
    };

    /**
     * Print a circle with the specified line width.
     *
     * @param x
     *            Horizontal position of the upper left corner of the drawn filled ellipse (in mm).
     * @param y
     *            Vertical position of the upper left corner of the drawn filled ellipse (in mm).
     * @param radius
     *            Draw the radius of the circle (in mm).
     * @param lineWidth
     *            Line width of a circle (in mm). The line width of a circle extends to the inside of the circle.
     * @return Print successful or not?
     */
    LPAPI.prototype.drawCircle = function (x, y, radius, lineWidth) {
        return this.DzLPAPI.drawCircle(x, y, radius, lineWidth);
    };

    /**
     * Print the filled circle.
     *
     * @param x
     *            Horizontal position of the upper left corner of the drawn filled ellipse (in mm).
     * @param y
     *            Vertical position of the upper left corner of the drawn filled ellipse (in mm).
     * @param radius
     *            The radius of the filled circle drawn (in mm).
     * @return Print successful or not?
     */
    LPAPI.prototype.fillCircle = function (x, y, radius) {
        return this.DzLPAPI.fillCircle(x, y, radius);
    };

    /**
     * Print line (straight/slash).
     *
     * @param x1
     *            Horizontal position of the starting point of the line (in mm).
     * @param y1
     *            Vertical position of the starting point of the line (in mm).
     * @param x2
     *            Horizontal position of the end point of the line (in mm).
     * @param y2
     *             Vertical position of the end point of the line (in mm).
     * @param lineWidth
     *             Line width (in mm). The line width is extended down the line.
     * @return Print successful or not?
     */
    LPAPI.prototype.drawLine = function (x1, y1, x2, y2, lineWidth) {
        return this.DzLPAPI.drawLine(x1, y1, x2, y2, lineWidth);
    };

    /**
     *  Print dotted lines.
     *
     * @param x1
     *            Horizontal position of the starting point of the line (in mm).
     * @param y1
     *            Vertical position of the starting point of the line (in mm).
     * @param x2
     *            Horizontal position of the end point of the line (in mm).
     * @param y2
     *            Vertical position of the end point of the line (in mm).
     * @param lineWidth
     *            Line width (in mm). The line width is extended down the line.
     * @param dashLen
     *            An array of dotted line segment lengths (in mm).
     * @param dashCount
     *             The number of elements in the dotted line segment length array.
     * @return Print successful or not?
     */
    LPAPI.prototype.drawDashLine = function (x1, y1, x2, y2, lineWidth, dashLen, dashCount) {
        return this.DzLPAPI.drawDashLine(x1, y1, x2, y2, lineWidth, dashLen, dashCount);
    };

    /**
     *  Print dotted lines.
     *
     * @param x1
     *            Horizontal position of the starting point of the line (in mm).
     * @param y1
     *           Vertical position of the starting point of the line (in mm).
     * @param x2
     *             Horizontal position of the end point of the line (in mm).
     * @param y2
     *            Vertical position of the end point of the line (in mm).
     * @param lineWidth
     *            Line width (in mm). The line width is extended down the line.
     * @param dashLen1
     *            Length of the first segment of the dotted line (in mm).
     * @param dashLen2
     *            Length of the second segment of the dotted line (in mm).
     * @return Print successful or not?
     */
    LPAPI.prototype.drawDashLine2 = function (x1, y1, x2, y2, lineWidth, dashLen1, dashLen2) {
        return this.DzLPAPI.drawDashLine2(x1, y1, x2, y2, lineWidth, dashLen1, dashLen2);
    };

    /**
     *  Print dotted lines.
     *
     * @param x1
     *            Horizontal position of the starting point of the line (in mm).
     * @param y1
     *            Vertical position of the starting point of the line (in mm).
     * @param x2
     *            Horizontal position of the end point of the line (in mm).
     * @param y2
     *            Vertical position of the end point of the line (in mm).
     * @param lineWidth
     *            Line width (in mm). The line width is extended down the line.
     * @param dashLen1
     *            Length of the first segment of the dotted line (in mm).
     * @param dashLen2
     *            Length of the second segment of the dotted line (in mm).
     * @param dashLen3
     *            Length of the third segment of the dotted line (in mm).
     * @param dashLen4
     *            Length of the fourth segment of the dotted line (in mm).
     * @return Print successful or not?
     */
    LPAPI.prototype.drawDashLine4 = function (x1, y1, x2, y2, lineWidth, dashLen1, dashLen2, dashLen3, dashLen4) {
        return this.DzLPAPI.drawDashLine4(x1, y1, x2, y2, lineWidth, dashLen1, dashLen2, dashLen3, dashLen4);
    };

    /**
     * Print Barcode
     *
     * @param text
     *            Content of  barcode to be drawn
     * @param type
     *            Refer to the document for the encoding type of barcodes.
     * @param x
     *            Horizontal position of the upper left corner of the drawn barcode (in mm).
     * @param y
     *            Vertical position of the upper left corner of the drawn 1D barcode (in mm).
     * @param width
     *            The overall display width of barcode.
     * @param height
     *             Height of the display of the barcode (including human readable text).
     * @param textHeight
     *             Height of human-readable text (in mm), recommended 3 mm.
     * @return Print successful or not?
     */
    LPAPI.prototype.draw1DBarcode = function (text, type, x, y, width, height, textHeight) {
        return this.DzLPAPI.draw1DBarcode(text, type || 60, x, y, width, height, textHeight);
    };

    /**
     * Print QR Code
     *
     * @param text
     *            The content of the QR code that needs to be drawn.
     * @param x
     *             Horizontal position of the upper left corner of the drawn QR code (in mm).
     * @param y
     *            Vertical position of the upper left corner of the drawn QR code (in mm).
     * @param width
     *            Horizontal width of the drawn QR code (in mm).
     * @return Print successful or not?
     */
    LPAPI.prototype.draw2DQRCode = function (text, x, y, width) {
        return this.DzLPAPI.draw2DQRCode(text, x, y, width);
    };

    /**
     * Print PDF417 QR Code.
     *
     * @param text
     *            The content of the PDF417 QR code that needs to be drawn.
     * @param x
     *            Horizontal position of the upper left corner of the drawn PDF417 QR code (in mm).
     * @param y
     *            Vertical position of the upper left corner of the drawn PDF417 QR code (in mm).
     * @param width
     *            Horizontal width of the drawn PDF417 QR code (in mm).
     * @param height
     *            Vertical height of the drawn PDF417 QR code (in mm).
     * @return Print successful or not?
     */
    LPAPI.prototype.draw2DPdf417 = function (text, x, y, width, height) {
        return this.DzLPAPI.draw2DPdf417(text, x, y, width, height);
    };

    /**
     * Print Image.
     *
     * @param imageFile
     *            Image Path.
     * @param x
     *            The position of the print object in the horizontal direction (in mm).
     * @param y
     *           The position of the print object in the vertical direction (in mm).
     * @param width
     *            The width of the print object (in mm).
     * @param height
     *            The height of the print object (in mm).
     * @return Print successful or not?
     */
    LPAPI.prototype.drawImage = function (imageFile, x, y, width, height) {
        return this.DzLPAPI.drawImage(imageFile, x, y, width, height);
    };

    /**
     * Print the image at the actual size of the given image.
     *
     * @param imageFile
     *            Image Path.
     * @param x
     *            The position of the print object in the horizontal direction (in mm).
     * @param y
     *             The position of the print object in the vertical direction (in mm).
     * @return Print successful or not?
     */
    LPAPI.prototype.drawImageWithActualSize = function (imageFile, x, y) {
        return this.DzLPAPI.drawImageWithActualSize(imageFile, x, y);
    };

    /**
     * Print Image.
     *
     * @param imageFile
     *            Image Path.
     * @param x
     *             The position of the print object in the horizontal direction (in mm).
     * @param y
     *            The position of the print object in the vertical direction (in mm).
     * @param width
     *            The width of the print object (in mm).
     * @param height
     *             The height of the print object (in mm).
     * @param threshold
     *            The grayscale threshold for drawing the bitmap.
     *            256 Indicates drawing a grayscale image;
     *            257 Indicates that the primary color picture is drawn;
     *            0 to 255 means that a black and white image is drawn, and points with original image color >= grayscale threshold are considered white, while points with original image color < grayscale threshold are considered black. The default value is 192.
     * @return Print successful or not?
     */
    LPAPI.prototype.drawImageWithThreshold = function (imageFile, x, y, width, height, threshold) {
        return this.DzLPAPI.drawImageWithThreshold(imageFile, x, y, width, height, threshold);
    };

    return LPAPI;
})();